==> shotcut_21.01.29+ds.orig.tar.xz: shotcut-21.01.29+ds/src/windowstools.cpp <==
/*
 * Copyright (c) 2012-2020 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "windowstools.h"

WindowsTaskbarButton::WindowsTaskbarButton()
{
}

WindowsTaskbarButton& WindowsTaskbarButton::getInstance()
{
    static WindowsTaskbarButton* instance = 0;
    if (!instance)
        instance = new WindowsTaskbarButton();
    return *instance;
}

void WindowsTaskbarButton::setParentWindow(QWidget* parent)
{
    m_taskbarButton = new QWinTaskbarButton(parent);
    m_taskbarButton->setWindow(parent->windowHandle());
    m_taskbarProgress = m_taskbarButton->progress();
}

void WindowsTaskbarButton::setProgress(int progress)
{
    if (m_taskbarProgress != NULL)
    {
        m_taskbarProgress->setVisible(true);
        m_taskbarProgress->setValue(progress);
    }
}

void WindowsTaskbarButton::resetProgress()
{
    if (m_taskbarProgress != NULL)
    {
        m_taskbarProgress->setVisible(false);
        m_taskbarProgress->reset();
    }
}

==> shotcut_24.02.29+ds.orig.tar.xz: shotcut-24.02.29+ds/src/windowstools.cpp <==
/*
 * Copyright (c) 2012-2020 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "windowstools.h"

WindowsTaskbarButton::WindowsTaskbarButton()
{
}

WindowsTaskbarButton &WindowsTaskbarButton::getInstance()
{
    static WindowsTaskbarButton *instance = 0;
    if (!instance)
        instance = new WindowsTaskbarButton();
    return *instance;
}

void WindowsTaskbarButton::setParentWindow(QWidget *parent)
{
    m_taskbarButton = new QWinTaskbarButton(parent);
    m_taskbarButton->setWindow(parent->windowHandle());
    m_taskbarProgress = m_taskbarButton->progress();
}

void WindowsTaskbarButton::setProgress(int progress)
{
    if (m_taskbarProgress != NULL) {
        m_taskbarProgress->setVisible(true);
        m_taskbarProgress->setValue(progress);
    }
}

void WindowsTaskbarButton::resetProgress()
{
    if (m_taskbarProgress != NULL) {
        m_taskbarProgress->setVisible(false);
        m_taskbarProgress->reset();
    }
}
